@@ -527,8 +527,12 @@ public class JspServletWrapper {
     protected JasperException handleJspException(Exception ex) {
         try {
             Throwable realException = ex;
+            // Unwrap Servlet exception once
             if (ex instanceof ServletException) {
-                realException = ((ServletException) ex).getRootCause();
+                Throwable rootCause = ((ServletException) ex).getRootCause();
+                if (rootCause != null) {
+                    realException = rootCause;
+                }
             }
 
             // Find the first stack frame that represents code generated by
