@@ -48,24 +48,19 @@ import org.apache.tomcat.websocket.WsWebSocketContainer;
 import org.apache.tomcat.websocket.pojo.PojoMethodMapping;
 
 /**
- * Provides a per class loader (i.e. per web application) instance of a
- * ServerContainer. Web application wide defaults may be configured by setting
- * the following servlet context initialisation parameters to the desired
- * values.
+ * Provides a per class loader (i.e. per web application) instance of a ServerContainer. Web application wide defaults
+ * may be configured by setting the following servlet context initialisation parameters to the desired values.
  * <ul>
  * <li>{@link Constants#BINARY_BUFFER_SIZE_SERVLET_CONTEXT_INIT_PARAM}</li>
  * <li>{@link Constants#TEXT_BUFFER_SIZE_SERVLET_CONTEXT_INIT_PARAM}</li>
  * </ul>
  */
-public class WsServerContainer extends WsWebSocketContainer
-        implements ServerContainer {
+public class WsServerContainer extends WsWebSocketContainer implements ServerContainer {
 
     private static final StringManager sm = StringManager.getManager(WsServerContainer.class);
 
-    private static final CloseReason AUTHENTICATED_HTTP_SESSION_CLOSED =
-            new CloseReason(CloseCodes.VIOLATED_POLICY,
-                    "This connection was established under an authenticated " +
-                    "HTTP session that has ended.");
+    private static final CloseReason AUTHENTICATED_HTTP_SESSION_CLOSED = new CloseReason(CloseCodes.VIOLATED_POLICY,
+            "This connection was established under an authenticated " + "HTTP session that has ended.");
 
     private final WsWriteTimeout wsWriteTimeout = new WsWriteTimeout();
 
@@ -74,8 +69,7 @@ public class WsServerContainer extends WsWebSocketContainer
     private final Map<Integer,ConcurrentSkipListMap<String,TemplatePathMatch>> configTemplateMatchMap =
             new ConcurrentHashMap<>();
     @SuppressWarnings("deprecation")
-    private volatile boolean enforceNoAddAfterHandshake =
-            org.apache.tomcat.websocket.Constants.STRICT_SPEC_COMPLIANCE;
+    private volatile boolean enforceNoAddAfterHandshake = org.apache.tomcat.websocket.Constants.STRICT_SPEC_COMPLIANCE;
     private volatile boolean addAllowed = true;
     private final Map<String,Set<WsSession>> authenticatedSessions = new ConcurrentHashMap<>();
     private volatile boolean endpointsRegistered = false;
@@ -88,43 +82,39 @@ public class WsServerContainer extends WsWebSocketContainer
         setInstanceManager((InstanceManager) servletContext.getAttribute(InstanceManager.class.getName()));
 
         // Configure servlet context wide defaults
-        String value = servletContext.getInitParameter(
-                Constants.BINARY_BUFFER_SIZE_SERVLET_CONTEXT_INIT_PARAM);
+        String value = servletContext.getInitParameter(Constants.BINARY_BUFFER_SIZE_SERVLET_CONTEXT_INIT_PARAM);
         if (value != null) {
             setDefaultMaxBinaryMessageBufferSize(Integer.parseInt(value));
         }
 
-        value = servletContext.getInitParameter(
-                Constants.TEXT_BUFFER_SIZE_SERVLET_CONTEXT_INIT_PARAM);
+        value = servletContext.getInitParameter(Constants.TEXT_BUFFER_SIZE_SERVLET_CONTEXT_INIT_PARAM);
         if (value != null) {
             setDefaultMaxTextMessageBufferSize(Integer.parseInt(value));
         }
 
-        value = servletContext.getInitParameter(
-                Constants.ENFORCE_NO_ADD_AFTER_HANDSHAKE_CONTEXT_INIT_PARAM);
+        value = servletContext.getInitParameter(Constants.ENFORCE_NO_ADD_AFTER_HANDSHAKE_CONTEXT_INIT_PARAM);
         if (value != null) {
             setEnforceNoAddAfterHandshake(Boolean.parseBoolean(value));
         }
 
-        FilterRegistration.Dynamic fr = servletContext.addFilter(
-                "Tomcat WebSocket (JSR356) Filter", new WsFilter());
-        fr.setAsyncSupported(true);
+        FilterRegistration.Dynamic fr = servletContext.addFilter("Tomcat WebSocket (JSR356) Filter", new WsFilter());
+        if (fr != null) {
+            fr.setAsyncSupported(true);
 
-        EnumSet<DispatcherType> types = EnumSet.of(DispatcherType.REQUEST,
-                DispatcherType.FORWARD);
+            EnumSet<DispatcherType> types = EnumSet.of(DispatcherType.REQUEST, DispatcherType.FORWARD);
 
-        fr.addMappingForUrlPatterns(types, true, "/*");
+            fr.addMappingForUrlPatterns(types, true, "/*");
+        }
     }
 
 
     /**
-     * Published the provided endpoint implementation at the specified path with
-     * the specified configuration. {@link #WsServerContainer(ServletContext)}
-     * must be called before calling this method.
+     * Published the provided endpoint implementation at the specified path with the specified configuration.
+     * {@link #WsServerContainer(ServletContext)} must be called before calling this method.
      *
-     * @param sec   The configuration to use when creating endpoint instances
-     * @throws DeploymentException if the endpoint cannot be published as
-     *         requested
+     * @param sec The configuration to use when creating endpoint instances
+     *
+     * @throws DeploymentException if the endpoint cannot be published as requested
      */
     @Override
     public void addEndpoint(ServerEndpointConfig sec) throws DeploymentException {
@@ -135,13 +125,11 @@ public class WsServerContainer extends WsWebSocketContainer
     void addEndpoint(ServerEndpointConfig sec, boolean fromAnnotatedPojo) throws DeploymentException {
 
         if (enforceNoAddAfterHandshake && !addAllowed) {
-            throw new DeploymentException(
-                    sm.getString("serverContainer.addNotAllowed"));
+            throw new DeploymentException(sm.getString("serverContainer.addNotAllowed"));
         }
 
         if (servletContext == null) {
-            throw new DeploymentException(
-                    sm.getString("serverContainer.servletContextMissing"));
+            throw new DeploymentException(sm.getString("serverContainer.servletContextMissing"));
         }
 
         if (deploymentFailed) {
@@ -153,10 +141,10 @@ public class WsServerContainer extends WsWebSocketContainer
             String path = sec.getPath();
 
             // Add method mapping to user properties
-            PojoMethodMapping methodMapping = new PojoMethodMapping(sec.getEndpointClass(),
-                    sec.getDecoders(), path, getInstanceManager(Thread.currentThread().getContextClassLoader()));
-            if (methodMapping.getOnClose() != null || methodMapping.getOnOpen() != null
-                    || methodMapping.getOnError() != null || methodMapping.hasMessageHandlers()) {
+            PojoMethodMapping methodMapping = new PojoMethodMapping(sec.getEndpointClass(), sec.getDecoders(), path,
+                    getInstanceManager(Thread.currentThread().getContextClassLoader()));
+            if (methodMapping.getOnClose() != null || methodMapping.getOnOpen() != null ||
+                    methodMapping.getOnError() != null || methodMapping.hasMessageHandlers()) {
                 sec.getUserProperties().put(org.apache.tomcat.websocket.pojo.Constants.POJO_METHOD_MAPPING_KEY,
                         methodMapping);
             }
@@ -164,8 +152,7 @@ public class WsServerContainer extends WsWebSocketContainer
             UriTemplate uriTemplate = new UriTemplate(path);
             if (uriTemplate.hasParameters()) {
                 Integer key = Integer.valueOf(uriTemplate.getSegmentCount());
-                ConcurrentSkipListMap<String,TemplatePathMatch> templateMatches =
-                        configTemplateMatchMap.get(key);
+                ConcurrentSkipListMap<String,TemplatePathMatch> templateMatches = configTemplateMatchMap.get(key);
                 if (templateMatches == null) {
                     // Ensure that if concurrent threads execute this block they
                     // all end up using the same ConcurrentSkipListMap instance
@@ -177,17 +164,15 @@ public class WsServerContainer extends WsWebSocketContainer
                 TemplatePathMatch oldMatch = templateMatches.putIfAbsent(uriTemplate.getNormalizedPath(), newMatch);
                 if (oldMatch != null) {
                     // Note: This depends on Endpoint instances being added
-                    //       before POJOs in WsSci#onStartup()
+                    // before POJOs in WsSci#onStartup()
                     if (oldMatch.isFromAnnotatedPojo() && !newMatch.isFromAnnotatedPojo() &&
                             oldMatch.getConfig().getEndpointClass() == newMatch.getConfig().getEndpointClass()) {
                         // The WebSocket spec says to ignore the new match in this case
                         templateMatches.put(path, oldMatch);
                     } else {
                         // Duplicate uriTemplate;
-                        throw new DeploymentException(
-                                sm.getString("serverContainer.duplicatePaths", path,
-                                             sec.getEndpointClass(),
-                                             sec.getEndpointClass()));
+                        throw new DeploymentException(sm.getString("serverContainer.duplicatePaths", path,
+                                sec.getEndpointClass(), sec.getEndpointClass()));
                     }
                 }
             } else {
@@ -196,17 +181,15 @@ public class WsServerContainer extends WsWebSocketContainer
                 ExactPathMatch oldMatch = configExactMatchMap.put(path, newMatch);
                 if (oldMatch != null) {
                     // Note: This depends on Endpoint instances being added
-                    //       before POJOs in WsSci#onStartup()
+                    // before POJOs in WsSci#onStartup()
                     if (oldMatch.isFromAnnotatedPojo() && !newMatch.isFromAnnotatedPojo() &&
                             oldMatch.getConfig().getEndpointClass() == newMatch.getConfig().getEndpointClass()) {
                         // The WebSocket spec says to ignore the new match in this case
                         configExactMatchMap.put(path, oldMatch);
                     } else {
                         // Duplicate path mappings
-                        throw new DeploymentException(
-                                sm.getString("serverContainer.duplicatePaths", path,
-                                             oldMatch.getConfig().getEndpointClass(),
-                                             sec.getEndpointClass()));
+                        throw new DeploymentException(sm.getString("serverContainer.duplicatePaths", path,
+                                oldMatch.getConfig().getEndpointClass(), sec.getEndpointClass()));
                     }
                 }
             }
@@ -220,11 +203,10 @@ public class WsServerContainer extends WsWebSocketContainer
 
 
     /**
-     * Provides the equivalent of {@link #addEndpoint(ServerEndpointConfig)}
-     * for publishing plain old java objects (POJOs) that have been annotated as
-     * WebSocket endpoints.
+     * Provides the equivalent of {@link #addEndpoint(ServerEndpointConfig)} for publishing plain old java objects
+     * (POJOs) that have been annotated as WebSocket endpoints.
      *
-     * @param pojo   The annotated POJO
+     * @param pojo The annotated POJO
      */
     @Override
     public void addEndpoint(Class<?> pojo) throws DeploymentException {
@@ -244,9 +226,7 @@ public class WsServerContainer extends WsWebSocketContainer
         try {
             ServerEndpoint annotation = pojo.getAnnotation(ServerEndpoint.class);
             if (annotation == null) {
-                throw new DeploymentException(
-                        sm.getString("serverContainer.missingAnnotation",
-                                pojo.getName()));
+                throw new DeploymentException(sm.getString("serverContainer.missingAnnotation", pojo.getName()));
             }
             String path = annotation.value();
 
@@ -254,25 +234,19 @@ public class WsServerContainer extends WsWebSocketContainer
             validateEncoders(annotation.encoders(), getInstanceManager(Thread.currentThread().getContextClassLoader()));
 
             // ServerEndpointConfig
-            Class<? extends Configurator> configuratorClazz =
-                    annotation.configurator();
+            Class<? extends Configurator> configuratorClazz = annotation.configurator();
             Configurator configurator = null;
             if (!configuratorClazz.equals(Configurator.class)) {
                 try {
                     configurator = annotation.configurator().getConstructor().newInstance();
                 } catch (ReflectiveOperationException e) {
-                    throw new DeploymentException(sm.getString(
-                            "serverContainer.configuratorFail",
-                            annotation.configurator().getName(),
-                            pojo.getClass().getName()), e);
+                    throw new DeploymentException(sm.getString("serverContainer.configuratorFail",
+                            annotation.configurator().getName(), pojo.getName()), e);
                 }
             }
-            sec = ServerEndpointConfig.Builder.create(pojo, path).
-                    decoders(Arrays.asList(annotation.decoders())).
-                    encoders(Arrays.asList(annotation.encoders())).
-                    subprotocols(Arrays.asList(annotation.subprotocols())).
-                    configurator(configurator).
-                    build();
+            sec = ServerEndpointConfig.Builder.create(pojo, path).decoders(Arrays.asList(annotation.decoders()))
+                    .encoders(Arrays.asList(annotation.encoders()))
+                    .subprotocols(Arrays.asList(annotation.subprotocols())).configurator(configurator).build();
         } catch (DeploymentException de) {
             failDeployment();
             throw de;
@@ -298,32 +272,25 @@ public class WsServerContainer extends WsWebSocketContainer
 
 
     /**
-     * Until the WebSocket specification provides such a mechanism, this Tomcat
-     * proprietary method is provided to enable applications to programmatically
-     * determine whether or not to upgrade an individual request to WebSocket.
+     * Until the WebSocket specification provides such a mechanism, this Tomcat proprietary method is provided to enable
+     * applications to programmatically determine whether or not to upgrade an individual request to WebSocket.
      * <p>
-     * Note: This method is not used by Tomcat but is used directly by
-     *       third-party code and must not be removed.
+     * Note: This method is not used by Tomcat but is used directly by third-party code and must not be removed.
      *
-     * @param request The request object to be upgraded
-     * @param response The response object to be populated with the result of
-     *                 the upgrade
-     * @param sec The server endpoint to use to process the upgrade request
+     * @param request    The request object to be upgraded
+     * @param response   The response object to be populated with the result of the upgrade
+     * @param sec        The server endpoint to use to process the upgrade request
      * @param pathParams The path parameters associated with the upgrade request
      *
-     * @throws ServletException If a configuration error prevents the upgrade
-     *         from taking place
-     * @throws IOException If an I/O error occurs during the upgrade process
+     * @throws ServletException If a configuration error prevents the upgrade from taking place
+     * @throws IOException      If an I/O error occurs during the upgrade process
      *
-     * @deprecated This method will be removed in Apache Tomcat 10.1 onwards. It
-     *             has been replaced by {@link #upgradeHttpToWebSocket(Object,
-     *             Object, ServerEndpointConfig, Map)}
+     * @deprecated This method will be removed in Apache Tomcat 10.1 onwards. It has been replaced by
+     *                 {@link #upgradeHttpToWebSocket(Object, Object, ServerEndpointConfig, Map)}
      */
     @Deprecated
-    public void doUpgrade(HttpServletRequest request,
-            HttpServletResponse response, ServerEndpointConfig sec,
-            Map<String,String> pathParams)
-            throws ServletException, IOException {
+    public void doUpgrade(HttpServletRequest request, HttpServletResponse response, ServerEndpointConfig sec,
+            Map<String,String> pathParams) throws ServletException, IOException {
         UpgradeUtil.doUpgrade(this, request, response, sec, pathParams);
     }
 
@@ -340,27 +307,29 @@ public class WsServerContainer extends WsWebSocketContainer
      * <p>
      * This method will be part of the Jakarta WebSocket API from version 2.1
      *
-     * @param httpServletRequest    The {@code HttpServletRequest} to be processed as a WebSocket handshake as per
-     *                              section 4.0 of RFC 6455.
-     * @param httpServletResponse   The {@code HttpServletResponse} to be used when processing the
-     *                              {@code httpServletRequest} as a WebSocket handshake as per section 4.0 of RFC 6455.
-     * @param sec                   The server endpoint configuration to use to configure the WebSocket endpoint
-     * @param pathParameters        Provides a mapping of path parameter names and values, if any, to be used for the
-     *                              WebSocket connection established by the call to this method. If no such mapping is
-     *                              defined, an empty Map must be passed.
+     * @param httpServletRequest  The {@code HttpServletRequest} to be processed as a WebSocket handshake as per section
+     *                                4.0 of RFC 6455.
+     * @param httpServletResponse The {@code HttpServletResponse} to be used when processing the
+     *                                {@code httpServletRequest} as a WebSocket handshake as per section 4.0 of RFC
+     *                                6455.
+     * @param sec                 The server endpoint configuration to use to configure the WebSocket endpoint
+     * @param pathParameters      Provides a mapping of path parameter names and values, if any, to be used for the
+     *                                WebSocket connection established by the call to this method. If no such mapping is
+     *                                defined, an empty Map must be passed.
      *
-     * @throws IllegalStateException if the provided request does not meet the requirements of the WebSocket handshake
+     * @throws IllegalStateException         if the provided request does not meet the requirements of the WebSocket
+     *                                           handshake
      * @throws UnsupportedOperationException if the WebSocket implementation is not deployed as part of a Jakarta
-     *                                       Servlet container
-     * @throws IOException if an I/O error occurs during the establishment of a WebSocket connection
-     * @throws DeploymentException if a configuration error prevents the establishment of a WebSocket connection
+     *                                           Servlet container
+     * @throws IOException                   if an I/O error occurs during the establishment of a WebSocket connection
+     * @throws DeploymentException           if a configuration error prevents the establishment of a WebSocket
+     *                                           connection
      */
-    public void upgradeHttpToWebSocket(Object httpServletRequest, Object httpServletResponse,
-            ServerEndpointConfig sec, Map<String, String> pathParameters)
-            throws IOException, DeploymentException {
+    public void upgradeHttpToWebSocket(Object httpServletRequest, Object httpServletResponse, ServerEndpointConfig sec,
+            Map<String,String> pathParameters) throws IOException, DeploymentException {
         try {
-            UpgradeUtil.doUpgrade(this, (HttpServletRequest) httpServletRequest, (HttpServletResponse) httpServletResponse,
-                    sec, pathParameters);
+            UpgradeUtil.doUpgrade(this, (HttpServletRequest) httpServletRequest,
+                    (HttpServletResponse) httpServletResponse, sec, pathParameters);
         } catch (ServletException e) {
             throw new DeploymentException(e.getMessage(), e);
         }
@@ -378,11 +347,11 @@ public class WsServerContainer extends WsWebSocketContainer
         // Check an exact match. Simple case as there are no templates.
         ExactPathMatch match = configExactMatchMap.get(path);
         if (match != null) {
-            return new WsMappingResult(match.getConfig(), Collections.<String, String>emptyMap());
+            return new WsMappingResult(match.getConfig(), Collections.emptyMap());
         }
 
         // No exact match. Need to look for template matches.
-        UriTemplate pathUriTemplate = null;
+        UriTemplate pathUriTemplate;
         try {
             pathUriTemplate = new UriTemplate(path);
         } catch (DeploymentException e) {
@@ -428,8 +397,7 @@ public class WsServerContainer extends WsWebSocketContainer
 
 
     @Deprecated
-    public void setEnforceNoAddAfterHandshake(
-            boolean enforceNoAddAfterHandshake) {
+    public void setEnforceNoAddAfterHandshake(boolean enforceNoAddAfterHandshake) {
         this.enforceNoAddAfterHandshake = enforceNoAddAfterHandshake;
     }
 
@@ -440,9 +408,7 @@ public class WsServerContainer extends WsWebSocketContainer
 
 
     /**
-     * {@inheritDoc}
-     *
-     * Overridden to make it visible to other classes in this package.
+     * {@inheritDoc} Overridden to make it visible to other classes in this package.
      */
     @Override
     protected InstanceManager getInstanceManager(ClassLoader classLoader) {
@@ -451,40 +417,30 @@ public class WsServerContainer extends WsWebSocketContainer
 
 
     /**
-     * {@inheritDoc}
-     *
-     * Overridden to make it visible to other classes in this package.
+     * {@inheritDoc} Overridden to make it visible to other classes in this package.
      */
     @Override
     protected void registerSession(Object key, WsSession wsSession) {
         super.registerSession(key, wsSession);
-        if (wsSession.isOpen() &&
-                wsSession.getUserPrincipal() != null &&
-                wsSession.getHttpSessionId() != null) {
-            registerAuthenticatedSession(wsSession,
-                    wsSession.getHttpSessionId());
+        if (wsSession.isOpen() && wsSession.getUserPrincipal() != null && wsSession.getHttpSessionId() != null) {
+            registerAuthenticatedSession(wsSession, wsSession.getHttpSessionId());
         }
     }
 
 
     /**
-     * {@inheritDoc}
-     *
-     * Overridden to make it visible to other classes in this package.
+     * {@inheritDoc} Overridden to make it visible to other classes in this package.
      */
     @Override
     protected void unregisterSession(Object key, WsSession wsSession) {
-        if (wsSession.getUserPrincipal() != null &&
-                wsSession.getHttpSessionId() != null) {
-            unregisterAuthenticatedSession(wsSession,
-                    wsSession.getHttpSessionId());
+        if (wsSession.getUserPrincipalInternal() != null && wsSession.getHttpSessionId() != null) {
+            unregisterAuthenticatedSession(wsSession, wsSession.getHttpSessionId());
         }
         super.unregisterSession(key, wsSession);
     }
 
 
-    private void registerAuthenticatedSession(WsSession wsSession,
-            String httpSessionId) {
+    private void registerAuthenticatedSession(WsSession wsSession, String httpSessionId) {
         Set<WsSession> wsSessions = authenticatedSessions.get(httpSessionId);
         if (wsSessions == null) {
             wsSessions = ConcurrentHashMap.newKeySet();
@@ -495,8 +451,7 @@ public class WsServerContainer extends WsWebSocketContainer
     }
 
 
-    private void unregisterAuthenticatedSession(WsSession wsSession,
-            String httpSessionId) {
+    private void unregisterAuthenticatedSession(WsSession wsSession, String httpSessionId) {
         Set<WsSession> wsSessions = authenticatedSessions.get(httpSessionId);
         // wsSessions will be null if the HTTP session has ended
         if (wsSessions != null) {
@@ -512,7 +467,7 @@ public class WsServerContainer extends WsWebSocketContainer
             for (WsSession wsSession : wsSessions) {
                 try {
                     wsSession.close(AUTHENTICATED_HTTP_SESSION_CLOSED);
-                } catch (IOException e) {
+                } catch (IOException ignore) {
                     // Any IOExceptions during close will have been caught and the
                     // onError method called.
                 }
@@ -536,9 +491,8 @@ public class WsServerContainer extends WsWebSocketContainer
                     instance = (Encoder) instanceManager.newInstance(encoder);
                     instanceManager.destroyInstance(instance);
                 }
-            } catch(ReflectiveOperationException | NamingException e) {
-                throw new DeploymentException(sm.getString(
-                        "serverContainer.encoderFail", encoder.getName()), e);
+            } catch (ReflectiveOperationException | NamingException e) {
+                throw new DeploymentException(sm.getString("serverContainer.encoderFail", encoder.getName()), e);
             }
         }
     }
@@ -549,8 +503,7 @@ public class WsServerContainer extends WsWebSocketContainer
         private final UriTemplate uriTemplate;
         private final boolean fromAnnotatedPojo;
 
-        TemplatePathMatch(ServerEndpointConfig config, UriTemplate uriTemplate,
-                boolean fromAnnotatedPojo) {
+        TemplatePathMatch(ServerEndpointConfig config, UriTemplate uriTemplate, boolean fromAnnotatedPojo) {
             this.config = config;
             this.uriTemplate = uriTemplate;
             this.fromAnnotatedPojo = fromAnnotatedPojo;
